Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterPhishingProtectionServiceV1Beta1Server(s grpc.ServiceRegistrar, srv PhishingProtectionServiceV1Beta1Server)
- type PhishingProtectionServiceV1Beta1Client
- type PhishingProtectionServiceV1Beta1Server
- type ReportPhishingRequest
- func (*ReportPhishingRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ReportPhishingRequest) GetParent() string
- func (x *ReportPhishingRequest) GetUri() string
- func (*ReportPhishingRequest) ProtoMessage()
- func (x *ReportPhishingRequest) ProtoReflect() protoreflect.Message
- func (x *ReportPhishingRequest) Reset()
- func (x *ReportPhishingRequest) String() string
- type ReportPhishingResponse
- type UnimplementedPhishingProtectionServiceV1Beta1Server
- type UnsafePhishingProtectionServiceV1Beta1Server
Constants ¶
const (
PhishingProtectionServiceV1Beta1_ReportPhishing_FullMethodName = "/google.cloud.phishingprotection.v1beta1.PhishingProtectionServiceV1Beta1/ReportPhishing"
)
Variables ¶
var File_google_cloud_phishingprotection_v1beta1_phishingprotection_proto protoreflect.FileDescriptor
var PhishingProtectionServiceV1Beta1_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.phishingprotection.v1beta1.PhishingProtectionServiceV1Beta1", HandlerType: (*PhishingProtectionServiceV1Beta1Server)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ReportPhishing", Handler: _PhishingProtectionServiceV1Beta1_ReportPhishing_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/phishingprotection/v1beta1/phishingprotection.proto", }
PhishingProtectionServiceV1Beta1_ServiceDesc is the grpc.ServiceDesc for PhishingProtectionServiceV1Beta1 service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterPhishingProtectionServiceV1Beta1Server ¶
func RegisterPhishingProtectionServiceV1Beta1Server(s grpc.ServiceRegistrar, srv PhishingProtectionServiceV1Beta1Server)
Types ¶
type PhishingProtectionServiceV1Beta1Client ¶
type PhishingProtectionServiceV1Beta1Client interface {
// Reports a URI suspected of containing phishing content to be reviewed. Once
// the report review is complete, its result can be found in the Cloud
// Security Command Center findings dashboard for Phishing Protection. If the
// result verifies the existence of malicious phishing content, the site will
// be added the to [Google's Social Engineering
// lists](https://support.google.com/webmasters/answer/6350487/) in order to
// protect users that could get exposed to this threat in the future.
ReportPhishing(ctx context.Context, in *ReportPhishingRequest, opts ...grpc.CallOption) (*ReportPhishingResponse, error)
}
PhishingProtectionServiceV1Beta1Client is the client API for PhishingProtectionServiceV1Beta1 service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewPhishingProtectionServiceV1Beta1Client ¶
func NewPhishingProtectionServiceV1Beta1Client(cc grpc.ClientConnInterface) PhishingProtectionServiceV1Beta1Client
type PhishingProtectionServiceV1Beta1Server ¶
type PhishingProtectionServiceV1Beta1Server interface {
// Reports a URI suspected of containing phishing content to be reviewed. Once
// the report review is complete, its result can be found in the Cloud
// Security Command Center findings dashboard for Phishing Protection. If the
// result verifies the existence of malicious phishing content, the site will
// be added the to [Google's Social Engineering
// lists](https://support.google.com/webmasters/answer/6350487/) in order to
// protect users that could get exposed to this threat in the future.
ReportPhishing(context.Context, *ReportPhishingRequest) (*ReportPhishingResponse, error)
}
PhishingProtectionServiceV1Beta1Server is the server API for PhishingProtectionServiceV1Beta1 service. All implementations should embed UnimplementedPhishingProtectionServiceV1Beta1Server for forward compatibility
type ReportPhishingRequest ¶
type ReportPhishingRequest struct {
// Required. The name of the project for which the report will be created,
// in the format "projects/{project_number}".
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. The URI that is being reported for phishing content to be analyzed.
Uri string `protobuf:"bytes,2,opt,name=uri,proto3" json:"uri,omitempty"`
// contains filtered or unexported fields
}
The ReportPhishing request message.
func (*ReportPhishingRequest) Descriptor
deprecated
func (*ReportPhishingRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReportPhishingRequest.ProtoReflect.Descriptor instead.
func (*ReportPhishingRequest) GetParent ¶
func (x *ReportPhishingRequest) GetParent() string
func (*ReportPhishingRequest) GetUri ¶
func (x *ReportPhishingRequest) GetUri() string
func (*ReportPhishingRequest) ProtoMessage ¶
func (*ReportPhishingRequest) ProtoMessage()
func (*ReportPhishingRequest) ProtoReflect ¶
func (x *ReportPhishingRequest) ProtoReflect() protoreflect.Message
func (*ReportPhishingRequest) Reset ¶
func (x *ReportPhishingRequest) Reset()
func (*ReportPhishingRequest) String ¶
func (x *ReportPhishingRequest) String() string
type ReportPhishingResponse ¶
type ReportPhishingResponse struct {
// contains filtered or unexported fields
}
The ReportPhishing (empty) response message.
func (*ReportPhishingResponse) Descriptor
deprecated
func (*ReportPhishingResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReportPhishingResponse.ProtoReflect.Descriptor instead.
func (*ReportPhishingResponse) ProtoMessage ¶
func (*ReportPhishingResponse) ProtoMessage()
func (*ReportPhishingResponse) ProtoReflect ¶
func (x *ReportPhishingResponse) ProtoReflect() protoreflect.Message
func (*ReportPhishingResponse) Reset ¶
func (x *ReportPhishingResponse) Reset()
func (*ReportPhishingResponse) String ¶
func (x *ReportPhishingResponse) String() string
type UnimplementedPhishingProtectionServiceV1Beta1Server ¶
type UnimplementedPhishingProtectionServiceV1Beta1Server struct {
}
UnimplementedPhishingProtectionServiceV1Beta1Server should be embedded to have forward compatible implementations.
func (UnimplementedPhishingProtectionServiceV1Beta1Server) ReportPhishing ¶
func (UnimplementedPhishingProtectionServiceV1Beta1Server) ReportPhishing(context.Context, *ReportPhishingRequest) (*ReportPhishingResponse, error)
type UnsafePhishingProtectionServiceV1Beta1Server ¶ added in v0.9.7
type UnsafePhishingProtectionServiceV1Beta1Server interface {
// contains filtered or unexported methods
}
UnsafePhishingProtectionServiceV1Beta1Server may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PhishingProtectionServiceV1Beta1Server will result in compilation errors.